@@ -34,7 +34,7 @@ extern "C" {
 
 Main goals and usage hints
 
-The main intention of this interface is to provide an universal portable and
+The main intention of this interface is to provide a universal portable and
 high performance access to file system functionality on any operating
 system.
 
@@ -74,7 +74,7 @@ for a "FileExists". This should only be done when processing a single file
 (i.e. before opening) and NEVER during enumeration of directory contents on
 any step of information processing. This would change the runtime behaviour
 from O(n) to O(n*n/2) on nearly every file system.  On Windows NT reading the
-contents of an directory with 7000 entries and getting full information about
+contents of a directory with 7000 entries and getting full information about
 every file only takes 0.6 seconds. Specifying the flag
 osl_FileStatus_Mask_Validate for each entry will increase the time to 180
 seconds (!!!).
@@ -151,7 +151,7 @@ typedef void *oslDirectoryItem;
     @retval osl_File_E_None on success
     @retval osl_File_E_INVAL the format of the parameters was not valid
     @retval osl_File_E_NOENT the specified path doesn't exist
-    @retval osl_File_E_NOTDIR the specified path is not an directory
+    @retval osl_File_E_NOTDIR the specified path is not a directory
     @retval osl_File_E_NOMEM not enough memory for allocating structures
     @retval osl_File_E_ACCES permission denied
     @retval osl_File_E_MFILE too many open files used by the process
@@ -717,8 +717,8 @@ SAL_DLLPUBLIC oslFileError SAL_CALL osl_openFile(
     @see    osl_openFile()
     @see    osl_getFilePos()
 */
-SAL_DLLPUBLIC oslFileError SAL_CALL osl_setFilePos(
-        oslFileHandle Handle, sal_uInt32 uHow, sal_Int64 uPos ) SAL_WARN_UNUSED_RESULT;
+SAL_WARN_UNUSED_RESULT SAL_DLLPUBLIC oslFileError SAL_CALL osl_setFilePos(
+        oslFileHandle Handle, sal_uInt32 uHow, sal_Int64 uPos );
 
 /** Retrieve the current position of the internal pointer of an open file.
 
@@ -1396,7 +1396,7 @@ SAL_DLLPUBLIC oslFileError SAL_CALL osl_getCanonicalName(
     Base directory URL to which the relative path is related to.
 
     @param[in] pustrRelativeFileURL
-    An URL of a file or directory relative to the directory path specified by pustrBaseDirectoryURL
+    A URL of a file or directory relative to the directory path specified by pustrBaseDirectoryURL
     or an absolute path.
     If pustrRelativeFileURL denotes an absolute path pustrBaseDirectoryURL will be ignored.
 
@@ -1634,6 +1634,37 @@ SAL_DLLPUBLIC oslFileError SAL_CALL osl_createTempFile(
     oslFileHandle* pHandle,
     rtl_uString**  ppustrTempFileURL);
 
+/** Move a file to a new destination or rename it, taking old file's identity (if exists).
+
+    Moves or renames a file, replacing an existing file if exist. If the old file existed,
+    moved file's metadata, e.g. creation time (on FSes which keep files' creation time) or
+    ACLs, are set to old one's (to keep the old file's identity) - currently this is only
+    implemented fully on Windows; on other platforms, this is mostly equivalent to osl_moveFile.
+
+    @param[in] pustrSourceFileURL
+    Full qualified URL of the source file.
+
+    @param[in] pustrDestFileURL
+    Full qualified URL of the destination file.
+
+    @retval osl_File_E_None on success
+    @retval osl_File_E_INVAL the format of the parameters was not valid
+    @retval osl_File_E_NOMEM not enough memory for allocating structures
+    @retval osl_File_E_ACCES permission denied
+    @retval osl_File_E_PERM operation not permitted
+    @retval osl_File_E_NAMETOOLONG file name too long
+    @retval osl_File_E_NOENT no such file
+    @retval osl_File_E_ROFS read-only file system
+    @retval osl_File_E_BUSY if the implementation internally requires resources that are
+        (temporarily) unavailable
+
+    @see osl_moveFile()
+
+    @since LibreOffice 6.2
+*/
+SAL_DLLPUBLIC oslFileError SAL_CALL osl_replaceFile(rtl_uString* pustrSourceFileURL,
+                                                    rtl_uString* pustrDestFileURL);
+
 #ifdef __cplusplus
 }
 #endif
